@@ -427,7 +427,7 @@ int ChimeraCheckCommand::execute(){
 			
 			
 			//break up file
-			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 				vector<unsigned long long> positions = m->divideFile(fastaFileNames[i], processors);
 			
 				for (int s = 0; s < (positions.size()-1); s++) {
@@ -522,7 +522,7 @@ int ChimeraCheckCommand::driver(linePair* filePos, string outputFName, string fi
 			}
 			delete candidateSeq;
 			
-			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 				unsigned long long pos = inFASTA.tellg();
 				if ((pos == -1) || (pos >= filePos->end)) { break; }
 			#else
@@ -599,7 +599,7 @@ int ChimeraCheckCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File
 
 int ChimeraCheckCommand::createProcesses(string outputFileName, string filename) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		int process = 0;
 		int num = 0;
 		
