@@ -26,6 +26,8 @@ class ChopSeqsCommand : public Command {
 		string getCommandName()			{ return "chop.seqs";		}
 		string getCommandCategory()		{ return "Sequence Processing"; }
 		string getHelpString();	
+		string getCitation() { return "http://www.mothur.org/wiki/Chops.seqs"; }
+		string getDescription()		{ return "trim sequence length"; }
 	
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }		
