@@ -238,7 +238,7 @@ void Classify::generateDatabaseAndNames(string tfile, string tempFile, string me
 	}
 }
 /**************************************************************************************************/
-Classify::Classify() {		m = MothurOut::getInstance();	database = NULL;	}
+Classify::Classify() {		m = MothurOut::getInstance();	database = NULL;	flipped=false; }
 /**************************************************************************************************/
 
 int Classify::readTaxonomy(string file) {
