@@ -30,7 +30,9 @@ public:
 	string getCommandName()			{ return "collect.shared";			}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
-	
+	string getCitation() { return "Schloss PD, Handelsman J (2006). Introducing SONS, A tool that compares the membership of microbial communities. Appl Environ Microbiol 72: 6773-9. \nhttp://www.mothur.org/wiki/Collect.shared"; }
+	string getDescription()		{ return "generates collector's curves for calculators, which describe the similarity between communities or their shared richness"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
