@@ -29,6 +29,8 @@ class Command {
 		virtual string getCommandName() = 0;
 		virtual string getCommandCategory() = 0;
 		virtual string getHelpString() = 0;
+		virtual string getCitation() = 0;
+		virtual string getDescription() = 0;
 		
 		virtual map<string, vector<string> > getOutputFiles() { return outputTypes; }
 		virtual vector<string> setParameters() = 0; //to fill parameters
@@ -36,6 +38,7 @@ class Command {
 	
 		virtual int execute() = 0;
 		virtual void help() = 0;
+		void citation() { m->mothurOutEndLine(); m->mothurOut(getCitation()); m->mothurOutEndLine(); }
 		virtual ~Command() { }
 	
 	protected:
