@@ -126,6 +126,10 @@
 #include "chimeraperseuscommand.h"
 #include "shhhseqscommand.h"
 #include "summaryqualcommand.h"
+#include "otuassociationcommand.h"
+#include "sortseqscommand.h"
+#include "classifytreecommand.h"
+#include "cooccurrencecommand.h"
 
 /*******************************************************/
 
@@ -273,6 +277,10 @@ CommandFactory::CommandFactory(){
 	commands["summary.tax"]			= "summary.tax";
 	commands["summary.qual"]		= "summary.qual";
 	commands["shhh.seqs"]			= "shhh.seqs";
+	commands["otu.association"]		= "otu.association";
+    commands["sort.seqs"]           = "sort.seqs";
+    commands["classify.tree"]       = "classify.tree";
+    commands["cooccurrence"]        = "cooccurrence";
 	commands["quit"]				= "MPIEnabled"; 
 
 }
@@ -433,6 +441,10 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "summary.qual")			{	command = new SummaryQualCommand(optionString);				}
 		else if(commandName == "chimera.perseus")		{	command = new ChimeraPerseusCommand(optionString);			}
 		else if(commandName == "shhh.seqs")				{	command = new ShhhSeqsCommand(optionString);				}
+		else if(commandName == "otu.association")		{	command = new OTUAssociationCommand(optionString);			}
+        else if(commandName == "sort.seqs")             {	command = new SortSeqsCommand(optionString);                }
+        else if(commandName == "classify.tree")         {	command = new ClassifyTreeCommand(optionString);            }
+        else if(commandName == "cooccurrence")          {	command = new CooccurrenceCommand(optionString);            }
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -577,6 +589,10 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "summary.qual")			{	pipecommand = new SummaryQualCommand(optionString);				}
 		else if(commandName == "chimera.perseus")		{	pipecommand = new ChimeraPerseusCommand(optionString);			}
 		else if(commandName == "shhh.seqs")				{	pipecommand = new ShhhSeqsCommand(optionString);				}
+		else if(commandName == "otu.association")		{	pipecommand = new OTUAssociationCommand(optionString);			}
+        else if(commandName == "sort.seqs")             {	pipecommand = new SortSeqsCommand(optionString);                }
+        else if(commandName == "classify.tree")         {	pipecommand = new ClassifyTreeCommand(optionString);            }
+        else if(commandName == "cooccurrence")          {	pipecommand = new CooccurrenceCommand(optionString);            }
 		else											{	pipecommand = new NoCommand(optionString);						}
 
 		return pipecommand;
@@ -709,6 +725,10 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "summary.qual")			{	shellcommand = new SummaryQualCommand();			}
 		else if(commandName == "chimera.perseus")		{	shellcommand = new ChimeraPerseusCommand();			}
 		else if(commandName == "shhh.seqs")				{	shellcommand = new ShhhSeqsCommand();				}
+		else if(commandName == "otu.association")		{	shellcommand = new OTUAssociationCommand();			}
+        else if(commandName == "sort.seqs")             {	shellcommand = new SortSeqsCommand();               }
+        else if(commandName == "classify.tree")         {	shellcommand = new ClassifyTreeCommand();           }
+        else if(commandName == "cooccurrence")          {	shellcommand = new CooccurrenceCommand();           }
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
@@ -734,7 +754,7 @@ Command* CommandFactory::getCommand(){
 		exit(1);
 	}
 }
-/***********************************************************************/
+***********************************************************************/
 bool CommandFactory::isValidCommand(string command) {
 	try {	
 	
