@@ -23,7 +23,9 @@ public:
 	string getCommandName()			{ return "degap.seqs";		}
 	string getCommandCategory()		{ return "Sequence Processing";		}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Degap.seqs"; }
+	string getDescription()		{ return "removes gap characters from sequences"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
