@@ -380,7 +380,7 @@ int DistanceCommand::execute(){
 		MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
 #else		
 				
-	//#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+	//#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		//if you don't need to fork anything
 		if(processors == 1){
 			if (output != "square") {  driver(0, numSeqs, outputFile, cutoff); }
@@ -507,7 +507,7 @@ int DistanceCommand::execute(){
 /**************************************************************************************************/
 void DistanceCommand::createProcesses(string filename) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		int process = 1;
 		processIDS.clear();
 		
@@ -1014,7 +1014,7 @@ int DistanceCommand::convertMatrix(string outputFile) {
 		string outfile = m->getRootName(outputFile) + "sorted.dist.temp";
 		
 		//use the unix sort 
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 			string command = "sort -n " + outputFile + " -o " + outfile;
 			system(command.c_str());
 		#else //sort using windows sort
@@ -1094,7 +1094,7 @@ int DistanceCommand::convertMatrix(string outputFile) {
 		exit(1);
 	}
 }
-/**************************************************************************************************
+**************************************************************************************************
 int DistanceCommand::convertToLowerTriangle(string outputFile) {
 	try{
 
@@ -1102,7 +1102,7 @@ int DistanceCommand::convertToLowerTriangle(string outputFile) {
 		string outfile = m->getRootName(outputFile) + "sorted.dist.temp";
 		
 		//use the unix sort 
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 			string command = "sort -n " + outputFile + " -o " + outfile;
 			system(command.c_str());
 		#else //sort using windows sort
@@ -1188,7 +1188,7 @@ int DistanceCommand::convertToLowerTriangle(string outputFile) {
 		exit(1);
 	}
 }
-/**************************************************************************************************/
+**************************************************************************************************/
 //its okay if the column file does not contain all the names in the fasta file, since some distance may have been above a cutoff,
 //but no sequences can be in the column file that are not in oldfasta. also, if a distance is above the cutoff given then remove it.
 //also check to make sure the 2 files have the same alignment length.
