@@ -28,6 +28,9 @@ public:
 	string getCommandName()			{ return "get.commandinfo";		}
 	string getCommandCategory()		{ return "Hidden";				}
 	string getHelpString();	
+	string getCitation() { return "no citation"; }
+	string getDescription()		{ return "get.commandinfo"; }
+	
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
