@@ -20,6 +20,7 @@ vector<string> GetGroupsCommand::setParameters(){
 		CommandParameter pshared("shared", "InputTypes", "", "", "none", "sharedGroup", "none",false,false); parameters.push_back(pshared);
 		CommandParameter pname("name", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pname);
 		CommandParameter pgroup("group", "InputTypes", "", "", "none", "sharedGroup", "FNGLT",false,false); parameters.push_back(pgroup);
+        CommandParameter pdesign("design", "InputTypes", "", "", "none", "sharedGroup", "FNGLT",false,false); parameters.push_back(pdesign);
 		CommandParameter plist("list", "InputTypes", "", "", "none", "none", "FNGLT",false,false); parameters.push_back(plist);
 		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "none", "FNGLT",false,false); parameters.push_back(ptaxonomy);
 		CommandParameter paccnos("accnos", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(paccnos);
@@ -40,9 +41,9 @@ vector<string> GetGroupsCommand::setParameters(){
 string GetGroupsCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The get.groups command selects sequences from a specfic group or set of groups from the following file types: fasta, name, group, list, taxonomy or shared file.\n";
+		helpString += "The get.groups command selects sequences from a specfic group or set of groups from the following file types: fasta, name, group, list, taxonomy, design or shared file.\n";
 		helpString += "It outputs a file containing the sequences in the those specified groups, or a sharedfile containing only those groups.\n";
-		helpString += "The get.groups command parameters are accnos, fasta, name, group, list, taxonomy, shared and groups. The group parameter is required, unless you have a current group file, or are using a shared file.\n";
+		helpString += "The get.groups command parameters are accnos, fasta, name, group, list, taxonomy, shared, design and groups. The group parameter is required, unless you have a current group file, or are using a shared file.\n";
 		helpString += "You must also provide an accnos containing the list of groups to get or set the groups parameter to the groups you wish to select.\n";
 		helpString += "The groups parameter allows you to specify which of the groups in your groupfile you would like.  You can separate group names with dashes.\n";
 		helpString += "The get.groups command should be in the following format: get.groups(accnos=yourAccnos, fasta=yourFasta, group=yourGroupFile).\n";
@@ -68,6 +69,7 @@ GetGroupsCommand::GetGroupsCommand(){
 		outputTypes["group"] = tempOutNames;
 		outputTypes["list"] = tempOutNames;
 		outputTypes["shared"] = tempOutNames;
+        outputTypes["design"] = tempOutNames;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "GetGroupsCommand", "GetGroupsCommand");
@@ -105,6 +107,7 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			outputTypes["group"] = tempOutNames;
 			outputTypes["list"] = tempOutNames;
 			outputTypes["shared"] = tempOutNames;
+            outputTypes["design"] = tempOutNames;
 			
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
@@ -170,6 +173,14 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
+                
+                it = parameters.find("design");
+				//user has given a template file
+				if(it != parameters.end()){ 
+					path = m->hasPath(it->second);
+					//if the user has not given a path then, add inputdir. else leave path alone.
+					if (path == "") {	parameters["design"] = inputDir + it->second;		}
+				}
 			}
 			
 			
@@ -180,12 +191,12 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			else { m->setAccnosFile(accnosfile); }
 			
 			fastafile = validParameter.validFile(parameters, "fasta", true);
-			if (fastafile == "not open") { abort = true; }
+			if (fastafile == "not open") { fastafile = ""; abort = true; }
 			else if (fastafile == "not found") {  fastafile = "";  }
 			else { m->setFastaFile(fastafile); }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
-			if (namefile == "not open") { abort = true; }
+			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found") {  namefile = "";  }	
 			else { m->setNameFile(namefile); }
 			
@@ -200,7 +211,7 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			else { m->setListFile(listfile); }
 			
 			taxfile = validParameter.validFile(parameters, "taxonomy", true);
-			if (taxfile == "not open") { abort = true; }
+			if (taxfile == "not open") { taxfile = ""; abort = true; }
 			else if (taxfile == "not found") {  taxfile = "";  }
 			else { m->setTaxonomyFile(taxfile); }
 			
@@ -219,9 +230,14 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") { groupfile = ""; abort = true; }
 			else if (groupfile == "not found") {  	groupfile = "";	}
-			else { m->setGroupFile(groupfile); }	
+			else { m->setGroupFile(groupfile); }
+            
+            designfile = validParameter.validFile(parameters, "design", true);
+			if (designfile == "not open") { designfile = ""; abort = true; }
+			else if (designfile == "not found") {  	designfile = "";	}
+			else { m->setDesignFile(designfile); }
 			
-			if ((sharedfile == "") && (groupfile == "")) { 
+			if ((sharedfile == "") && (groupfile == "") && (designfile == "")) { 
 				//is there are current file available for any of these?
 				if ((namefile != "") || (fastafile != "") || (listfile != "") || (taxfile != "")) {
 					//give priority to group, then shared
@@ -242,7 +258,11 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 						groupfile = m->getGroupFile(); 
 						if (groupfile != "") { m->mothurOut("Using " + groupfile + " as input file for the group parameter."); m->mothurOutEndLine(); }
 						else { 
-							m->mothurOut("You have no current groupfile or sharedfile and one is required."); m->mothurOutEndLine(); abort = true;
+							designfile = m->getDesignFile(); 
+                            if (designfile != "") { m->mothurOut("Using " + designfile + " as input file for the design parameter."); m->mothurOutEndLine(); }
+                            else { 
+                                m->mothurOut("You have no current groupfile or sharedfile or designfile and one is required."); m->mothurOutEndLine(); abort = true;
+                            }
 						}
 					}
 				}
@@ -250,9 +270,13 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			
 			if ((accnosfile == "") && (Groups.size() == 0)) { m->mothurOut("You must provide an accnos file or specify groups using the groups parameter."); m->mothurOutEndLine(); abort = true; }
 			
-			if ((fastafile == "") && (namefile == "") && (groupfile == "")  && (sharedfile == "") && (listfile == "") && (taxfile == ""))  { m->mothurOut("You must provide at least one of the following: fasta, name, taxonomy, group, shared or list."); m->mothurOutEndLine(); abort = true; }
+			if ((fastafile == "") && (namefile == "") && (groupfile == "")  && (designfile == "") && (sharedfile == "") && (listfile == "") && (taxfile == ""))  { m->mothurOut("You must provide at least one of the following: fasta, name, taxonomy, group, shared, design or list."); m->mothurOutEndLine(); abort = true; }
 			if ((groupfile == "") && ((namefile != "") || (fastafile != "") || (listfile != "") || (taxfile != "")))  { m->mothurOut("If using a fasta, name, taxonomy, group or list, then you must provide a group file."); m->mothurOutEndLine(); abort = true; }
 
+			if ((namefile == "") && ((fastafile != "") || (taxfile != ""))){
+				vector<string> files; files.push_back(fastafile); files.push_back(taxfile);
+				parser.getNameFile(files);
+			}
 		}
 		
 	}
@@ -298,6 +322,7 @@ int GetGroupsCommand::execute(){
 		if (listfile != "")			{		readList();		}
 		if (taxfile != "")			{		readTax();		}
 		if (sharedfile != "")		{		readShared();	}
+        if (designfile != "")		{		readDesign();	}
 		
 		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 		
@@ -339,6 +364,11 @@ int GetGroupsCommand::execute(){
 			if (itTypes != outputTypes.end()) {
 				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
 			}
+            
+            itTypes = outputTypes.find("design");
+			if (itTypes != outputTypes.end()) {
+				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setDesignFile(current); }
+			}
 		}
 		
 		return 0;		
@@ -684,6 +714,56 @@ int GetGroupsCommand::readGroup(){
 		exit(1);
 	}
 }
+//**********************************************************************************************************************
+int GetGroupsCommand::readDesign(){
+	try {
+		string thisOutputDir = outputDir;
+		if (outputDir == "") {  thisOutputDir += m->hasPath(designfile);  }
+		string outputFileName = thisOutputDir + m->getRootName(m->getSimpleName(designfile)) + "pick" + m->getExtension(designfile);
+		
+		ofstream out;
+		m->openOutputFile(outputFileName, out);
+		
+		ifstream in;
+		m->openInputFile(designfile, in);
+		string name, group;
+		
+		bool wroteSomething = false;
+		int selectedCount = 0;
+		
+		while(!in.eof()){
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			
+			in >> name;				//read from first column
+			in >> group;			//read from second column
+			
+			//if this name is in the accnos file
+			if (m->inUsersGroups(name, Groups)) {
+				wroteSomething = true;
+				out << name << '\t' << group << endl;
+                selectedCount++;
+			}
+			
+			m->gobble(in);
+		}
+		in.close();
+		out.close();
+		
+		if (wroteSomething == false) {  m->mothurOut("Your file does NOT contain groups from the groups you wish to get."); m->mothurOutEndLine();  }
+		outputTypes["design"].push_back(outputFileName); outputNames.push_back(outputFileName);
+		
+		m->mothurOut("Selected " + toString(selectedCount) + " groups from your design file."); m->mothurOutEndLine();
+        
+		
+		return 0;
+	}
+	catch(exception& e) {
+		m->errorOut(e, "GetGroupsCommand", "readDesign");
+		exit(1);
+	}
+}
+
+
 //**********************************************************************************************************************
 int GetGroupsCommand::readTax(){
 	try {
