@@ -28,6 +28,9 @@ public:
 	string getCommandName()			{ return "get.otus";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Get.otus"; }
+	string getDescription()		{ return "outputs a new list file containing the otus containing sequences from the groups specified"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
