@@ -26,6 +26,9 @@ public:
 	string getCommandName()			{ return "get.rabund";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Get.rabund"; }
+	string getDescription()		{ return "creates a rabund file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
