@@ -24,7 +24,9 @@ class GetSeqsCommand : public Command {
 		string getCommandName()			{ return "get.seqs";				}
 		string getCommandCategory()		{ return "Sequence Processing";		}
 		string getHelpString();	
-	
+		string getCitation() { return "http://www.mothur.org/wiki/Get.seqs"; }
+		string getDescription()		{ return "gets sequences from a list, fasta, name, group, alignreport, quality or taxonomy file"; }
+
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
 	
