@@ -29,6 +29,9 @@ public:
 	string getCommandName()			{ return "heatmap.bin";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Heatmap.bin"; }
+	string getDescription()		{ return "generate a heatmap where the color represents the relative abundanceof an OTU"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
