@@ -25,7 +25,9 @@ public:
 	string getCommandName()			{ return "help";		}
 	string getCommandCategory()		{ return "Hidden";		}
 	string getHelpString() { return "For more information about a specific command type 'commandName(help)' i.e. 'cluster(help)'"; }	
-	
+	string getCitation() { return "no citation"; }
+	string getDescription()		{ return "help"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
