@@ -21,10 +21,12 @@ class ListSeqsCommand : public Command {
 		~ListSeqsCommand(){}
 	
 		vector<string> setParameters();
-		string getCommandName()			{ return "get.seqs";				}
+		string getCommandName()			{ return "list.seqs";				}
 		string getCommandCategory()		{ return "Sequence Processing";		}
 		string getHelpString();	
-	
+		string getCitation() { return "http://www.mothur.org/wiki/List.seqs"; }
+		string getDescription()		{ return "lists sequences from a list, fasta, name, group, alignreport or taxonomy file"; }
+
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
 	
