@@ -23,7 +23,9 @@ public:
 	string getCommandName()			{ return "make.group";	}
 	string getCommandCategory()		{ return "General";		}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Make.group"; }
+	string getDescription()		{ return "creates a group file"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
