@@ -23,6 +23,9 @@ public:
 	string getCommandName()			{ return "merge.files";	}
 	string getCommandCategory()		{ return "General";		}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Merge.files"; }
+	string getDescription()		{ return "appends files creating one file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
