@@ -10,7 +10,7 @@
 #include "metastatscommand.h"
 #include "metastats.h"
 #include "sharedutilities.h"
-#include "mothurmetastats.h"
+
 
 //**********************************************************************************************************************
 vector<string> MetaStatsCommand::setParameters(){	
@@ -232,21 +232,19 @@ int MetaStatsCommand::execute(){
 		//only 1 combo
 		if (numGroups == 2) { processors = 1; }
 		else if (numGroups < 2)	{ m->mothurOut("Not enough sets, I need at least 2 valid sets. Unable to complete command."); m->mothurOutEndLine(); m->control_pressed = true; }
-		
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-			if(processors != 1){
-				int numPairs = namesOfGroupCombos.size();
-				int numPairsPerProcessor = numPairs / processors;
+
+        if(processors != 1){
+            int numPairs = namesOfGroupCombos.size();
+            int numPairsPerProcessor = numPairs / processors;
 			
-				for (int i = 0; i < processors; i++) {
-					int startPos = i * numPairsPerProcessor;
-					if(i == processors - 1){
-						numPairsPerProcessor = numPairs - i * numPairsPerProcessor;
-					}
-					lines.push_back(linePair(startPos, numPairsPerProcessor));
-				}
-			}
-		#endif
+            for (int i = 0; i < processors; i++) {
+                int startPos = i * numPairsPerProcessor;
+                if(i == processors - 1){
+                    numPairsPerProcessor = numPairs - i * numPairsPerProcessor;
+                }
+                lines.push_back(linePair(startPos, numPairsPerProcessor));
+            }
+        }
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
@@ -339,13 +337,13 @@ int MetaStatsCommand::execute(){
 int MetaStatsCommand::process(vector<SharedRAbundVector*>& thisLookUp){
 	try {
 		
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+		
 				if(processors == 1){
 					driver(0, namesOfGroupCombos.size(), thisLookUp);
 				}else{
 					int process = 1;
 					vector<int> processIDS;
-		
+		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 					//loop through and create all the processes you want
 					while (process != processors) {
 						int pid = fork();
@@ -371,11 +369,67 @@ int MetaStatsCommand::process(vector<SharedRAbundVector*>& thisLookUp){
 						int temp = processIDS[i];
 						wait(&temp);
 					}
-				}
-		#else
-				driver(0, namesOfGroupCombos.size(), thisLookUp);
-		#endif
+        #else
+                    
+                    //////////////////////////////////////////////////////////////////////////////////////////////////////
+                    //Windows version shared memory, so be careful when passing variables through the summarySharedData struct. 
+                    //Above fork() will clone, so memory is separate, but that's not the case with windows, 
+                    //Taking advantage of shared memory to pass results vectors.
+                    //////////////////////////////////////////////////////////////////////////////////////////////////////
+                    
+                    vector<metastatsData*> pDataArray; 
+                    DWORD   dwThreadIdArray[processors-1];
+                    HANDLE  hThreadArray[processors-1]; 
+                    
+                    //Create processor worker threads.
+                    for( int i=1; i<processors; i++ ){
+                        
+                        //make copy of lookup so we don't get access violations
+                        vector<SharedRAbundVector*> newLookup;
+                        vector<string> designMapGroups;
+                        for (int k = 0; k < thisLookUp.size(); k++) {
+                            SharedRAbundVector* temp = new SharedRAbundVector();
+                            temp->setLabel(thisLookUp[k]->getLabel());
+                            temp->setGroup(thisLookUp[k]->getGroup());
+                            newLookup.push_back(temp);
+                            designMapGroups.push_back(designMap->getGroup(thisLookUp[k]->getGroup()));
+                        }
+                        
+                        //for each bin
+                        for (int k = 0; k < thisLookUp[0]->getNumBins(); k++) {
+                            if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
+                            for (int j = 0; j < thisLookUp.size(); j++) { newLookup[j]->push_back(thisLookUp[j]->getAbundance(k), thisLookUp[j]->getGroup()); }
+                        }
+                        
+                        // Allocate memory for thread data.
+                        metastatsData* tempSum = new metastatsData(sharedfile, outputDir, m, lines[i].start, lines[i].num, namesOfGroupCombos, newLookup, designMapGroups, iters, threshold);
+                        pDataArray.push_back(tempSum);
+                        processIDS.push_back(i);
+                        
+                        hThreadArray[i-1] = CreateThread(NULL, 0, MyMetastatsThreadFunction, pDataArray[i-1], 0, &dwThreadIdArray[i-1]);   
+                    }
+                    
+                    //do my part
+					driver(lines[0].start, lines[0].num, thisLookUp);
+                    
+                    //Wait until all threads have terminated.
+                    WaitForMultipleObjects(processors-1, hThreadArray, TRUE, INFINITE);
+                    
+                    //Close all thread handles and free memory allocations.
+                    for(int i=0; i < pDataArray.size(); i++){
+                        for (int j = 0; j < pDataArray[i]->thisLookUp.size(); j++) {  delete pDataArray[i]->thisLookUp[j];  } 
+                        for (int j = 0; j < pDataArray[i]->outputNames.size(); j++) {  
+                            outputNames.push_back(pDataArray[i]->outputNames[j]);
+                            outputTypes["metastats"].push_back(pDataArray[i]->outputNames[j]);
+                        }
+                                                
+                        CloseHandle(hThreadArray[i]);
+                        delete pDataArray[i];
+                    }
+        #endif
 
+				}
+		
 		return 0;
 		
 	}
@@ -394,7 +448,7 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 			//get set names
 			string setA = namesOfGroupCombos[c][0]; 
 			string setB = namesOfGroupCombos[c][1];
-		//cout << setA << '\t' << setB << endl;
+		
 			//get filename
 			string outputFileName = outputDir +  m->getRootName(m->getSimpleName(sharedfile)) + thisLookUp[0]->getLabel() + "." + setA + "-" + setB + ".metastats";
 			outputNames.push_back(outputFileName); outputTypes["metastats"].push_back(outputFileName);
@@ -424,10 +478,7 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 					setACount++;
 				}
 			}
-			
-			//for (int i = 0; i < subset.size(); i++) { cout << designMap->getGroup(subset[i]->getGroup()) << endl; }
-			//cout << setACount << endl;
-			
+						
 			if ((setACount == 0) || (setBCount == 0))  { 
 				m->mothurOut("Missing shared info for " + setA + " or " + setB + ". Skipping comparison."); m->mothurOutEndLine(); 
 				outputNames.pop_back();
