@@ -25,6 +25,9 @@ public:
 	string getCommandName()			{ return "NoCommand";	}
 	string getCommandCategory()		{ return "Hidden";		}
 	string getHelpString() { return "No Command"; }	
+	string getCitation() { return "no citation"; }
+	string getDescription()		{ return "no description"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
