@@ -25,6 +25,9 @@ public:
 	string getCommandName()			{ return "normalize.shared";		}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Normalize.shared"; }
+	string getDescription()		{ return "normalize samples in a shared or relabund file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -41,8 +44,8 @@ private:
 	int norm;
 	vector<string> Groups, outputNames;
 		
-	int normalize(vector<SharedRAbundVector*>&, ofstream&);
-	int normalize(vector<SharedRAbundFloatVector*>&, ofstream&);
+	int normalize(vector<SharedRAbundVector*>&);
+	int normalize(vector<SharedRAbundFloatVector*>&);
 	int eliminateZeroOTUS(vector<SharedRAbundVector*>&);
 	int eliminateZeroOTUS(vector<SharedRAbundFloatVector*>&);
 
