@@ -25,6 +25,9 @@ public:
 	string getCommandName()			{ return "otu.hierarchy";			}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Otu.hierarchy"; }
+	string getDescription()		{ return "relates OTUs at different distances"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
