@@ -27,6 +27,8 @@ public:
 	string getCommandName()			{ return "parse.list";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Parse.list"; }
+	string getDescription()		{ return "parses a list file by group"; }
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
