@@ -54,7 +54,7 @@ EstOutput Parsimony::getValues(Tree* t, int p, string o) {
 			}
 		}
 		
-	#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+	#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		if(processors == 1){
 			data = driver(t, namesOfGroupCombos, 0, namesOfGroupCombos.size());
 		}else{
@@ -91,7 +91,7 @@ EstOutput Parsimony::getValues(Tree* t, int p, string o) {
 
 EstOutput Parsimony::createProcesses(Tree* t, vector< vector<string> > namesOfGroupCombos) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		int process = 1;
 		vector<int> processIDS;
 		
