@@ -26,7 +26,9 @@ public:
 	string getCommandName()			{ return "pcoa";					}
 	string getCommandCategory()		{ return "Hypothesis Testing";		}
 	string getHelpString();	
-	
+	string getCitation() { return "McCune B, Grace JB, Urban DL (2002). Analysis of ecological communities. MjM Software Design: Gleneden Beach, OR. \nLegendre P, Legendre L (1998). Numerical Ecology. Elsevier: New York. \nhttp://www.mothur.org/wiki/Pcoa"; }
+	string getDescription()		{ return "pcoa"; }
+
 	int execute();
 	void help() { m->mothurOut(getHelpString()); }
 	
