@@ -27,6 +27,9 @@ public:
 	string getCommandName()			{ return "pipeline.pds";	}
 	string getCommandCategory()		{ return "Hidden";			}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Pipeline.pds"; }
+	string getDescription()		{ return "pat's pipeline"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
