@@ -147,7 +147,7 @@ PreClusterCommand::PreClusterCommand(string option) {
 			// ...at some point should added some additional type checking...
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not found") { namefile =  "";  }
-			else if (namefile == "not open") { abort = true; }	
+			else if (namefile == "not open") { namefile = ""; abort = true; }	
 			else {  m->setNameFile(namefile); }
 			
 			groupfile = validParameter.validFile(parameters, "group", true);
@@ -162,7 +162,10 @@ PreClusterCommand::PreClusterCommand(string option) {
 			m->setProcessors(temp);
 			m->mothurConvert(temp, processors);
 			
-			
+			if (namefile == "") {
+				vector<string> files; files.push_back(fastafile);
+				parser.getNameFile(files);
+			}
 		}
 				
 	}
@@ -299,7 +302,7 @@ int PreClusterCommand::createProcessesGroups(SequenceParser* parser, string newF
 			lines.push_back(linePair(startIndex, endIndex));
 		}
 		
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)		
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)		
 		
 		//loop through and create all the processes you want
 		while (process != processors) {
@@ -511,7 +514,7 @@ int PreClusterCommand::readFASTA(){
 		m->openInputFile(fastafile, inFasta);
 		
 		//string firstCol, secondCol, nameString;
-		length = 0;
+		set<int> lengths;
 		
 		while (!inFasta.eof()) {
 			
@@ -537,17 +540,21 @@ int PreClusterCommand::readFASTA(){
 					else{
 						seqPNode tempNode(itSize->second, seq, names[seq.getName()]);
 						alignSeqs.push_back(tempNode);
-						if (seq.getAligned().length() > length) {  length = seq.getAligned().length();  }
+						lengths.insert(seq.getAligned().length());
 					}	
 				}else { //no names file, you are identical to yourself 
 					seqPNode tempNode(1, seq, seq.getName());
 					alignSeqs.push_back(tempNode);
-					if (seq.getAligned().length() > length) {  length = seq.getAligned().length();  }
+					lengths.insert(seq.getAligned().length());
 				}
 			}
 		}
 		inFasta.close();
 		//inNames.close();
+        
+        if (lengths.size() > 1) { m->control_pressed = true; m->mothurOut("[ERROR]: your sequences are not all the same length. pre.cluster requires sequences to be aligned."); m->mothurOutEndLine(); }
+        else if (lengths.size() == 1) { length = *(lengths.begin()); }
+        
 		return alignSeqs.size();
 	}
 	
@@ -559,7 +566,7 @@ int PreClusterCommand::readFASTA(){
 /**************************************************************************************************/
 int PreClusterCommand::loadSeqs(map<string, string>& thisName, vector<Sequence>& thisSeqs){
 	try {
-		length = 0;
+		set<int> lengths;
 		alignSeqs.clear();
 		map<string, string>::iterator it;
 		bool error = false;
@@ -582,15 +589,18 @@ int PreClusterCommand::loadSeqs(map<string, string>& thisName, vector<Sequence>&
 					
 					seqPNode tempNode(numReps, thisSeqs[i], it->second);
 					alignSeqs.push_back(tempNode);
-					if (thisSeqs[i].getAligned().length() > length) {  length = thisSeqs[i].getAligned().length();  }
+                    lengths.insert(thisSeqs[i].getAligned().length());
 				}	
 			}else { //no names file, you are identical to yourself 
 				seqPNode tempNode(1, thisSeqs[i], thisSeqs[i].getName());
 				alignSeqs.push_back(tempNode);
-				if (thisSeqs[i].getAligned().length() > length) {  length = thisSeqs[i].getAligned().length();  }
+				lengths.insert(thisSeqs[i].getAligned().length());
 			}
 		}
 		
+        if (lengths.size() > 1) { error = true; m->mothurOut("[ERROR]: your sequences are not all the same length. pre.cluster requires sequences to be aligned."); m->mothurOutEndLine(); }
+        else if (lengths.size() == 1) { length = *(lengths.begin()); }
+        
 		//sanity check
 		if (error) { m->control_pressed = true; }
 		
