@@ -27,6 +27,9 @@ public:
 	string getCommandName()			{ return "remove.rare";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Remove.rare"; }
+	string getDescription()		{ return "removes rare sequences from a sabund, rabund, shared or list and group file"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
