@@ -176,7 +176,7 @@ SeqErrorCommand::SeqErrorCommand(string option)  {
 				if (queryFileName != "") { m->mothurOut("Using " + queryFileName + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current fasta file and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
 			}
-			else if (queryFileName == "not open") { abort = true; }	
+			else if (queryFileName == "not open") { queryFileName = ""; abort = true; }	
 			else { m->setFastaFile(queryFileName); }
 			
 			referenceFileName = validParameter.validFile(parameters, "reference", true);
@@ -246,6 +246,11 @@ SeqErrorCommand::SeqErrorCommand(string option)  {
 
 			substitutionMatrix.resize(6);
 			for(int i=0;i<6;i++){	substitutionMatrix[i].resize(6,0);	}
+			
+			if ((namesFileName == "") && (queryFileName != "")){
+				vector<string> files; files.push_back(queryFileName); 
+				parser.getNameFile(files);
+			}
 		}
 	}
 	catch(exception& e) {
@@ -293,7 +298,7 @@ int SeqErrorCommand::execute(){
 		if(qualFileName == "")	{	qLines = lines;	rLines = lines; } //fills with duds
 		
 		int numSeqs = 0;
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		if(processors == 1){
 			numSeqs = driver(queryFileName, qualFileName, reportFileName, errorSummaryFileName, errorSeqFileName, errorChimeraFileName, lines[0], qLines[0], rLines[0]);
 		}else{
@@ -361,7 +366,7 @@ int SeqErrorCommand::createProcesses(string filename, string qFileName, string r
 		processIDS.clear();
 		map<char, vector<int> >::iterator it;
 		int num = 0;
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		
 		//loop through and create all the processes you want
 		while (process != processors) {
@@ -734,7 +739,7 @@ int SeqErrorCommand::driver(string filename, string qFileName, string rFileName,
 			
 			index++;
 			
-			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 				unsigned long long pos = queryFile.tellg();
 				if ((pos == -1) || (pos >= line.end)) { break; }
 			#else
@@ -1210,7 +1215,7 @@ void SeqErrorCommand::printQualityFR(vector<vector<int> > qualForwardMap, vector
 
 int SeqErrorCommand::setLines(string filename, string qfilename, string rfilename, vector<unsigned long long>& fastaFilePos, vector<unsigned long long>& qfileFilePos, vector<unsigned long long>& rfileFilePos) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		//set file positions for fasta file
 		fastaFilePos = m->divideFile(filename, processors);
 		
