@@ -26,7 +26,9 @@ public:
 	string getCommandName()			{ return "set.dir";		}
 	string getCommandCategory()		{ return "General";		}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Set.dir"; }
+	string getDescription()		{ return "set input, output and default directories"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
