@@ -26,7 +26,9 @@ public:
 	string getCommandName()			{ return "set.logfile";		}
 	string getCommandCategory()		{ return "General";			}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Set.logfile"; }
+	string getDescription()		{ return "set logfile name"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
