@@ -33,7 +33,7 @@ EstOutput Anderberg::getValues(vector<SharedRAbundVector*> shared) {
 			if ((tempA != 0) && (tempB != 0)) {	S12++; }
 		}
 		
-		data[0] = S12 / ((float)((2 * S1) + (2 * S2) - (3 * S12)));
+		data[0] = 1.0 - S12 / ((float)((2 * S1) + (2 * S2) - (3 * S12)));
 		
 		if (isnan(data[0]) || isinf(data[0])) { data[0] = 0; }
 		
