@@ -161,10 +161,16 @@ ShhhSeqsCommand::ShhhSeqsCommand(string option) {
 			
 			string temp	= validParameter.validFile(parameters, "sigma", false);		if(temp == "not found"){	temp = "0.01"; }
 			m->mothurConvert(temp, sigma); 
-			
+			sigma = 1/sigma;
+            
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
 			m->mothurConvert(temp, processors);
+			
+			if (namefile == "") {
+				vector<string> files; files.push_back(fastafile);
+				parser.getNameFile(files);
+			}
 		}
 	}
 	catch(exception& e) {
@@ -358,7 +364,7 @@ vector<string> ShhhSeqsCommand::createProcessesGroups(SequenceParser& parser, st
 			lines.push_back(linePair(startIndex, endIndex));
 		}
 		
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)		
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)		
 		
 		//loop through and create all the processes you want
 		while (process != processors) {
