@@ -31,19 +31,16 @@ public:
 	string getCommandName()			{ return "split.group";				}
 	string getCommandCategory()		{ return "Sequence Processing";		}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Split.group"; }
+	string getDescription()		{ return "split a name or fasta file by group"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-	int readNames(); 
-	int splitFasta(); 
-	
 	vector<string> outputNames;
-	map<string, vector<string> > nameMap;
-	map<string, vector<string> >::iterator itNames;
-	GroupMap* groupMap;
-	
+		
 	string outputDir, namefile, groupfile, groups, fastafile;
 	vector<string> Groups;
 	bool abort;
