@@ -29,7 +29,9 @@ public:
 	string getCommandName()			{ return "sub.sample";	}
 	string getCommandCategory()		{ return "General";		}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Sub.sample"; }
+	string getDescription()		{ return "get a sampling of sequences from a list, shared, rabund, sabund or fasta file"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
@@ -49,7 +51,7 @@ private:
 	int getSubSampleRabund();
 	int getSubSampleSabund();
 	int getSubSampleFasta();
-	int processShared(vector<SharedRAbundVector*>&, ofstream&);
+	int processShared(vector<SharedRAbundVector*>&);
 	int processRabund(RAbundVector*&, ofstream&);
 	int processSabund(SAbundVector*&, ofstream&);
 	int processList(ListVector*&, ofstream&, set<string>&);
