@@ -141,7 +141,7 @@ UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 			
 			//check for required parameters
 			treefile = validParameter.validFile(parameters, "tree", true);
-			if (treefile == "not open") { abort = true; }
+			if (treefile == "not open") { treefile = ""; abort = true; }
 			else if (treefile == "not found") { 				//if there is a current design file, use it
 				treefile = m->getTreeFile(); 
 				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
@@ -155,7 +155,7 @@ UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 			else { m->setGroupFile(groupfile); }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
-			if (namefile == "not open") { abort = true; }
+			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found") { namefile = ""; }
 			else { m->setNameFile(namefile); }
 			
@@ -192,6 +192,11 @@ UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 			m->mothurConvert(temp, processors);
 			
 			if (!random) {  iters = 0;  } //turn off random calcs
+			
+			if (namefile == "") {
+				vector<string> files; files.push_back(treefile);
+				parser.getNameFile(files);
+			}
 		}
 		
 		
@@ -337,7 +342,7 @@ int UnifracWeightedCommand::execute() {
 				
 				lines.clear();
 				
-				#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+				#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 					if(processors != 1){
 						int numPairs = namesOfGroupCombos.size();
 						int numPairsPerProcessor = numPairs / processors;
@@ -356,7 +361,7 @@ int UnifracWeightedCommand::execute() {
 				//get scores for random trees
 				for (int j = 0; j < iters; j++) {
 				
-					#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+					#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 						if(processors == 1){
 							driver(T[i],  namesOfGroupCombos, 0, namesOfGroupCombos.size(),  rScores);
 						}else{
@@ -454,7 +459,7 @@ int UnifracWeightedCommand::execute() {
 
 int UnifracWeightedCommand::createProcesses(Tree* t, vector< vector<string> > namesOfGroupCombos, vector< vector<double> >& scores) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		int process = 1;
 		vector<int> processIDS;
 		
